# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: auth_service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import auth_common_pb2 as auth__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12\x61uth_service.proto\x12\x18\x61rmonik.api.grpc.v1.auth\x1a\x11\x61uth_common.proto2\x87\x01\n\x0e\x41uthentication\x12u\n\x0eGetCurrentUser\x12/.armonik.api.grpc.v1.auth.GetCurrentUserRequest\x1a\x30.armonik.api.grpc.v1.auth.GetCurrentUserResponse\"\x00\x42\x1b\xaa\x02\x18\x41rmoniK.Api.gRPC.V1.Authb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'auth_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\030ArmoniK.Api.gRPC.V1.Auth'
  _globals['_AUTHENTICATION']._serialized_start=68
  _globals['_AUTHENTICATION']._serialized_end=203
# @@protoc_insertion_point(module_scope)
