# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: events_service.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..common import events_common_pb2 as events__common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x65vents_service.proto\x12\x1a\x61rmonik.api.grpc.v1.events\x1a\x13\x65vents_common.proto2\x84\x01\n\x06\x45vents\x12z\n\tGetEvents\x12\x34.armonik.api.grpc.v1.events.EventSubscriptionRequest\x1a\x35.armonik.api.grpc.v1.events.EventSubscriptionResponse0\x01\x42\x1d\xaa\x02\x1a\x41rmoniK.Api.gRPC.V1.Eventsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'events_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\032ArmoniK.Api.gRPC.V1.Events'
  _globals['_EVENTS']._serialized_start=74
  _globals['_EVENTS']._serialized_end=206
# @@protoc_insertion_point(module_scope)
