# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sessions_common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import session_status_pb2 as session__status__pb2
from . import sessions_fields_pb2 as sessions__fields__pb2
from . import sessions_filters_pb2 as sessions__filters__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15sessions_common.proto\x12\x1c\x61rmonik.api.grpc.v1.sessions\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14session_status.proto\x1a\x15sessions_fields.proto\x1a\x16sessions_filters.proto\x1a\x14sort_direction.proto\"\xd1\x03\n\nSessionRaw\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x41\n\x06status\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatus\x12\x19\n\x11\x63lient_submission\x18\x08 \x01(\x08\x12\x19\n\x11worker_submission\x18\t \x01(\x08\x12\x15\n\rpartition_ids\x18\x03 \x03(\t\x12\x31\n\x07options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0c\x63\x61ncelled_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpurged_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x08\x64uration\x18\x07 \x01(\x0b\x32\x19.google.protobuf.Duration\"\xd9\x02\n\x13ListSessionsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x36\n\x07\x66ilters\x18\x03 \x01(\x0b\x32%.armonik.api.grpc.v1.sessions.Filters\x12\x44\n\x04sort\x18\x04 \x01(\x0b\x32\x36.armonik.api.grpc.v1.sessions.ListSessionsRequest.Sort\x12\x19\n\x11with_task_options\x18\x05 \x01(\x08\x1a\x87\x01\n\x04Sort\x12\x39\n\x05\x66ield\x18\x01 \x01(\x0b\x32*.armonik.api.grpc.v1.sessions.SessionField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x82\x01\n\x14ListSessionsResponse\x12:\n\x08sessions\x18\x01 \x03(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\'\n\x11GetSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"O\n\x12GetSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14\x43\x61ncelSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15\x43\x61ncelSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"l\n\x14\x43reateSessionRequest\x12=\n\x13\x64\x65\x66\x61ult_task_option\x18\x01 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12\x15\n\rpartition_ids\x18\x02 \x03(\t\"(\n\x12\x43reateSessionReply\x12\x12\n\nsession_id\x18\x01 \x01(\t\")\n\x13PauseSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"Q\n\x14PauseSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14ResumeSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15ResumeSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\")\n\x13PurgeSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"Q\n\x14PurgeSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"*\n\x14\x44\x65leteSessionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"R\n\x15\x44\x65leteSessionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRaw\"K\n\x15StopSubmissionRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x0e\n\x06\x63lient\x18\x02 \x01(\x08\x12\x0e\n\x06worker\x18\x03 \x01(\x08\"S\n\x16StopSubmissionResponse\x12\x39\n\x07session\x18\x01 \x01(\x0b\x32(.armonik.api.grpc.v1.sessions.SessionRawB\x1f\xaa\x02\x1c\x41rmoniK.Api.gRPC.V1.Sessionsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sessions_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\034ArmoniK.Api.gRPC.V1.Sessions'
  _globals['_SESSIONRAW']._serialized_start=227
  _globals['_SESSIONRAW']._serialized_end=692
  _globals['_LISTSESSIONSREQUEST']._serialized_start=695
  _globals['_LISTSESSIONSREQUEST']._serialized_end=1040
  _globals['_LISTSESSIONSREQUEST_SORT']._serialized_start=905
  _globals['_LISTSESSIONSREQUEST_SORT']._serialized_end=1040
  _globals['_LISTSESSIONSRESPONSE']._serialized_start=1043
  _globals['_LISTSESSIONSRESPONSE']._serialized_end=1173
  _globals['_GETSESSIONREQUEST']._serialized_start=1175
  _globals['_GETSESSIONREQUEST']._serialized_end=1214
  _globals['_GETSESSIONRESPONSE']._serialized_start=1216
  _globals['_GETSESSIONRESPONSE']._serialized_end=1295
  _globals['_CANCELSESSIONREQUEST']._serialized_start=1297
  _globals['_CANCELSESSIONREQUEST']._serialized_end=1339
  _globals['_CANCELSESSIONRESPONSE']._serialized_start=1341
  _globals['_CANCELSESSIONRESPONSE']._serialized_end=1423
  _globals['_CREATESESSIONREQUEST']._serialized_start=1425
  _globals['_CREATESESSIONREQUEST']._serialized_end=1533
  _globals['_CREATESESSIONREPLY']._serialized_start=1535
  _globals['_CREATESESSIONREPLY']._serialized_end=1575
  _globals['_PAUSESESSIONREQUEST']._serialized_start=1577
  _globals['_PAUSESESSIONREQUEST']._serialized_end=1618
  _globals['_PAUSESESSIONRESPONSE']._serialized_start=1620
  _globals['_PAUSESESSIONRESPONSE']._serialized_end=1701
  _globals['_RESUMESESSIONREQUEST']._serialized_start=1703
  _globals['_RESUMESESSIONREQUEST']._serialized_end=1745
  _globals['_RESUMESESSIONRESPONSE']._serialized_start=1747
  _globals['_RESUMESESSIONRESPONSE']._serialized_end=1829
  _globals['_PURGESESSIONREQUEST']._serialized_start=1831
  _globals['_PURGESESSIONREQUEST']._serialized_end=1872
  _globals['_PURGESESSIONRESPONSE']._serialized_start=1874
  _globals['_PURGESESSIONRESPONSE']._serialized_end=1955
  _globals['_DELETESESSIONREQUEST']._serialized_start=1957
  _globals['_DELETESESSIONREQUEST']._serialized_end=1999
  _globals['_DELETESESSIONRESPONSE']._serialized_start=2001
  _globals['_DELETESESSIONRESPONSE']._serialized_end=2083
  _globals['_STOPSUBMISSIONREQUEST']._serialized_start=2085
  _globals['_STOPSUBMISSIONREQUEST']._serialized_end=2160
  _globals['_STOPSUBMISSIONRESPONSE']._serialized_start=2162
  _globals['_STOPSUBMISSIONRESPONSE']._serialized_end=2245
# @@protoc_insertion_point(module_scope)
