# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: tasks_common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from . import objects_pb2 as objects__pb2
from . import sort_direction_pb2 as sort__direction__pb2
from . import task_status_pb2 as task__status__pb2
from . import tasks_fields_pb2 as tasks__fields__pb2
from . import tasks_filters_pb2 as tasks__filters__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x12tasks_common.proto\x12\x19\x61rmonik.api.grpc.v1.tasks\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\robjects.proto\x1a\x14sort_direction.proto\x1a\x11task_status.proto\x1a\x12tasks_fields.proto\x1a\x13tasks_filters.proto\"\x86\x08\n\x0cTaskDetailed\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\x03 \x01(\t\x12\x17\n\x0finitial_task_id\x18\x16 \x01(\t\x12\x17\n\x0fparent_task_ids\x18\x04 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x05 \x03(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x06 \x03(\t\x12\x14\n\x0cretry_of_ids\x18\x07 \x03(\t\x12;\n\x06status\x18\x08 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\n \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breceived_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61\x63quired_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cprocessed_at\x18\x18 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07pod_ttl\x18\x0f \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x18\x63reation_to_end_duration\x18\x14 \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1aprocessing_to_end_duration\x18\x15 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18received_to_end_duration\x18\x17 \x01(\x0b\x32\x19.google.protobuf.Duration\x12>\n\x06output\x18\x10 \x01(\x0b\x32..armonik.api.grpc.v1.tasks.TaskDetailed.Output\x12\x14\n\x0cpod_hostname\x18\x11 \x01(\t\x1a(\n\x06Output\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\r\n\x05\x65rror\x18\x02 \x01(\t\"\xc2\x07\n\x0bTaskSummary\x12\n\n\x02id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\x12\x14\n\x0cowner_pod_id\x18\n \x01(\t\x12\x17\n\x0finitial_task_id\x18\x16 \x01(\t\x12\x1d\n\x15\x63ount_parent_task_ids\x18\x15 \x01(\x03\x12\x1f\n\x17\x63ount_data_dependencies\x18\x0b \x01(\x03\x12!\n\x19\x63ount_expected_output_ids\x18\r \x01(\x03\x12\x1a\n\x12\x63ount_retry_of_ids\x18\x0e \x01(\x03\x12;\n\x06status\x18\x04 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\x12\x16\n\x0estatus_message\x18\t \x01(\t\x12\x31\n\x07options\x18\x03 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0csubmitted_at\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0breceived_at\x18\x12 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x61\x63quired_at\x18\x13 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nstarted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x30\n\x0cprocessed_at\x18\x17 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nded_at\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07pod_ttl\x18\x14 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x18\x63reation_to_end_duration\x18\x0f \x01(\x0b\x32\x19.google.protobuf.Duration\x12=\n\x1aprocessing_to_end_duration\x18\x10 \x01(\x0b\x32\x19.google.protobuf.Duration\x12;\n\x18received_to_end_duration\x18\x18 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\r\n\x05\x65rror\x18\x08 \x01(\t\x12\x14\n\x0cpod_hostname\x18\x11 \x01(\t\"\xc1\x02\n\x10ListTasksRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x33\n\x07\x66ilters\x18\x03 \x01(\x0b\x32\".armonik.api.grpc.v1.tasks.Filters\x12>\n\x04sort\x18\x04 \x01(\x0b\x32\x30.armonik.api.grpc.v1.tasks.ListTasksRequest.Sort\x12\x13\n\x0bwith_errors\x18\x05 \x01(\x08\x1a\x81\x01\n\x04Sort\x12\x33\n\x05\x66ield\x18\x01 \x01(\x0b\x32$.armonik.api.grpc.v1.tasks.TaskField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"z\n\x11ListTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"\x83\x01\n\x19ListTasksDetailedResponse\x12\x36\n\x05tasks\x18\x01 \x03(\x0b\x32\'.armonik.api.grpc.v1.tasks.TaskDetailed\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\"!\n\x0eGetTaskRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\"H\n\x0fGetTaskResponse\x12\x35\n\x04task\x18\x01 \x01(\x0b\x32\'.armonik.api.grpc.v1.tasks.TaskDetailed\"&\n\x12\x43\x61ncelTasksRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"L\n\x13\x43\x61ncelTasksResponse\x12\x35\n\x05tasks\x18\x01 \x03(\x0b\x32&.armonik.api.grpc.v1.tasks.TaskSummary\"&\n\x13GetResultIdsRequest\x12\x0f\n\x07task_id\x18\x01 \x03(\t\"\xa1\x01\n\x14GetResultIdsResponse\x12S\n\x0ctask_results\x18\x01 \x03(\x0b\x32=.armonik.api.grpc.v1.tasks.GetResultIdsResponse.MapTaskResult\x1a\x34\n\rMapTaskResult\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x12\n\nresult_ids\x18\x02 \x03(\t\"P\n\x19\x43ountTasksByStatusRequest\x12\x33\n\x07\x66ilters\x18\x01 \x01(\x0b\x32\".armonik.api.grpc.v1.tasks.Filters\"N\n\x1a\x43ountTasksByStatusResponse\x12\x30\n\x06status\x18\x01 \x03(\x0b\x32 .armonik.api.grpc.v1.StatusCount\"\xca\x02\n\x12SubmitTasksRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x36\n\x0ctask_options\x18\x02 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12R\n\x0etask_creations\x18\x03 \x03(\x0b\x32:.armonik.api.grpc.v1.tasks.SubmitTasksRequest.TaskCreation\x1a\x93\x01\n\x0cTaskCreation\x12\x1c\n\x14\x65xpected_output_keys\x18\x01 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x02 \x03(\t\x12\x12\n\npayload_id\x18\x03 \x01(\t\x12\x36\n\x0ctask_options\x18\x04 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\"\xcb\x01\n\x13SubmitTasksResponse\x12K\n\ntask_infos\x18\x01 \x03(\x0b\x32\x37.armonik.api.grpc.v1.tasks.SubmitTasksResponse.TaskInfo\x1ag\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1b\n\x13\x65xpected_output_ids\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x12\x12\n\npayload_id\x18\x04 \x01(\tB\x1c\xaa\x02\x19\x41rmoniK.Api.gRPC.V1.Tasksb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tasks_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\031ArmoniK.Api.gRPC.V1.Tasks'
  _globals['_TASKDETAILED']._serialized_start=212
  _globals['_TASKDETAILED']._serialized_end=1242
  _globals['_TASKDETAILED_OUTPUT']._serialized_start=1202
  _globals['_TASKDETAILED_OUTPUT']._serialized_end=1242
  _globals['_TASKSUMMARY']._serialized_start=1245
  _globals['_TASKSUMMARY']._serialized_end=2207
  _globals['_LISTTASKSREQUEST']._serialized_start=2210
  _globals['_LISTTASKSREQUEST']._serialized_end=2531
  _globals['_LISTTASKSREQUEST_SORT']._serialized_start=2402
  _globals['_LISTTASKSREQUEST_SORT']._serialized_end=2531
  _globals['_LISTTASKSRESPONSE']._serialized_start=2533
  _globals['_LISTTASKSRESPONSE']._serialized_end=2655
  _globals['_LISTTASKSDETAILEDRESPONSE']._serialized_start=2658
  _globals['_LISTTASKSDETAILEDRESPONSE']._serialized_end=2789
  _globals['_GETTASKREQUEST']._serialized_start=2791
  _globals['_GETTASKREQUEST']._serialized_end=2824
  _globals['_GETTASKRESPONSE']._serialized_start=2826
  _globals['_GETTASKRESPONSE']._serialized_end=2898
  _globals['_CANCELTASKSREQUEST']._serialized_start=2900
  _globals['_CANCELTASKSREQUEST']._serialized_end=2938
  _globals['_CANCELTASKSRESPONSE']._serialized_start=2940
  _globals['_CANCELTASKSRESPONSE']._serialized_end=3016
  _globals['_GETRESULTIDSREQUEST']._serialized_start=3018
  _globals['_GETRESULTIDSREQUEST']._serialized_end=3056
  _globals['_GETRESULTIDSRESPONSE']._serialized_start=3059
  _globals['_GETRESULTIDSRESPONSE']._serialized_end=3220
  _globals['_GETRESULTIDSRESPONSE_MAPTASKRESULT']._serialized_start=3168
  _globals['_GETRESULTIDSRESPONSE_MAPTASKRESULT']._serialized_end=3220
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_start=3222
  _globals['_COUNTTASKSBYSTATUSREQUEST']._serialized_end=3302
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_start=3304
  _globals['_COUNTTASKSBYSTATUSRESPONSE']._serialized_end=3382
  _globals['_SUBMITTASKSREQUEST']._serialized_start=3385
  _globals['_SUBMITTASKSREQUEST']._serialized_end=3715
  _globals['_SUBMITTASKSREQUEST_TASKCREATION']._serialized_start=3568
  _globals['_SUBMITTASKSREQUEST_TASKCREATION']._serialized_end=3715
  _globals['_SUBMITTASKSRESPONSE']._serialized_start=3718
  _globals['_SUBMITTASKSRESPONSE']._serialized_end=3921
  _globals['_SUBMITTASKSRESPONSE_TASKINFO']._serialized_start=3818
  _globals['_SUBMITTASKSRESPONSE_TASKINFO']._serialized_end=3921
# @@protoc_insertion_point(module_scope)
