# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: applications_common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import applications_fields_pb2 as applications__fields__pb2
from . import applications_filters_pb2 as applications__filters__pb2
from . import sort_direction_pb2 as sort__direction__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61pplications_common.proto\x12 armonik.api.grpc.v1.applications\x1a\x19\x61pplications_fields.proto\x1a\x1a\x61pplications_filters.proto\x1a\x14sort_direction.proto\"S\n\x0e\x41pplicationRaw\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x11\n\tnamespace\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"\xd7\x02\n\x17ListApplicationsRequest\x12\x0c\n\x04page\x18\x01 \x01(\x05\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12:\n\x07\x66ilters\x18\x03 \x01(\x0b\x32).armonik.api.grpc.v1.applications.Filters\x12L\n\x04sort\x18\x04 \x01(\x0b\x32>.armonik.api.grpc.v1.applications.ListApplicationsRequest.Sort\x1a\x90\x01\n\x04Sort\x12\x42\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x32.armonik.api.grpc.v1.applications.ApplicationField\x12\x44\n\tdirection\x18\x02 \x01(\x0e\x32\x31.armonik.api.grpc.v1.sort_direction.SortDirection\"\x92\x01\n\x18ListApplicationsResponse\x12\x46\n\x0c\x61pplications\x18\x01 \x03(\x0b\x32\x30.armonik.api.grpc.v1.applications.ApplicationRaw\x12\x0c\n\x04page\x18\x02 \x01(\x05\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\r\n\x05total\x18\x04 \x01(\x05\x42#\xaa\x02 ArmoniK.Api.gRPC.V1.Applicationsb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'applications_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002 ArmoniK.Api.gRPC.V1.Applications'
  _globals['_APPLICATIONRAW']._serialized_start=140
  _globals['_APPLICATIONRAW']._serialized_end=223
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_start=226
  _globals['_LISTAPPLICATIONSREQUEST']._serialized_end=569
  _globals['_LISTAPPLICATIONSREQUEST_SORT']._serialized_start=425
  _globals['_LISTAPPLICATIONSREQUEST_SORT']._serialized_end=569
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_start=572
  _globals['_LISTAPPLICATIONSRESPONSE']._serialized_end=718
# @@protoc_insertion_point(module_scope)
