# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: submitter_common.proto
# Protobuf Python Version: 4.25.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import objects_pb2 as objects__pb2
from . import result_status_pb2 as result__status__pb2
from . import session_status_pb2 as session__status__pb2
from . import task_status_pb2 as task__status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16submitter_common.proto\x12\x1d\x61rmonik.api.grpc.v1.submitter\x1a\robjects.proto\x1a\x13result_status.proto\x1a\x14session_status.proto\x1a\x11task_status.proto\"=\n\x0bSessionList\x12.\n\x08sessions\x18\x01 \x03(\x0b\x32\x1c.armonik.api.grpc.v1.Session\"$\n\rSessionIdList\x12\x13\n\x0bsession_ids\x18\x01 \x03(\t\"l\n\x14\x43reateSessionRequest\x12=\n\x13\x64\x65\x66\x61ult_task_option\x18\x01 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12\x15\n\rpartition_ids\x18\x02 \x03(\t\"(\n\x12\x43reateSessionReply\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\x9d\x01\n\x16\x43reateSmallTaskRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x36\n\x0ctask_options\x18\x02 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptions\x12\x37\n\rtask_requests\x18\x03 \x03(\x0b\x32 .armonik.api.grpc.v1.TaskRequest\"\xc9\x02\n\x16\x43reateLargeTaskRequest\x12Y\n\x0cinit_request\x18\x01 \x01(\x0b\x32\x41.armonik.api.grpc.v1.submitter.CreateLargeTaskRequest.InitRequestH\x00\x12\x39\n\tinit_task\x18\x02 \x01(\x0b\x32$.armonik.api.grpc.v1.InitTaskRequestH\x00\x12\x36\n\x0ctask_payload\x18\x03 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x1aY\n\x0bInitRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x36\n\x0ctask_options\x18\x02 \x01(\x0b\x32 .armonik.api.grpc.v1.TaskOptionsB\x06\n\x04type\"\xe6\x03\n\x0f\x43reateTaskReply\x12\x61\n\x14\x63reation_status_list\x18\x01 \x01(\x0b\x32\x41.armonik.api.grpc.v1.submitter.CreateTaskReply.CreationStatusListH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x1ah\n\x08TaskInfo\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x1c\n\x14\x65xpected_output_keys\x18\x02 \x03(\t\x12\x19\n\x11\x64\x61ta_dependencies\x18\x03 \x03(\t\x12\x12\n\npayload_id\x18\x04 \x01(\t\x1ay\n\x0e\x43reationStatus\x12L\n\ttask_info\x18\x01 \x01(\x0b\x32\x37.armonik.api.grpc.v1.submitter.CreateTaskReply.TaskInfoH\x00\x12\x0f\n\x05\x65rror\x18\x02 \x01(\tH\x00\x42\x08\n\x06Status\x1an\n\x12\x43reationStatusList\x12X\n\x11\x63reation_statuses\x18\x01 \x03(\x0b\x32=.armonik.api.grpc.v1.submitter.CreateTaskReply.CreationStatusB\n\n\x08Response\"\xb9\x03\n\nTaskFilter\x12G\n\x07session\x18\x01 \x01(\x0b\x32\x34.armonik.api.grpc.v1.submitter.TaskFilter.IdsRequestH\x00\x12\x44\n\x04task\x18\x03 \x01(\x0b\x32\x34.armonik.api.grpc.v1.submitter.TaskFilter.IdsRequestH\x00\x12M\n\x08included\x18\x04 \x01(\x0b\x32\x39.armonik.api.grpc.v1.submitter.TaskFilter.StatusesRequestH\x01\x12M\n\x08\x65xcluded\x18\x05 \x01(\x0b\x32\x39.armonik.api.grpc.v1.submitter.TaskFilter.StatusesRequestH\x01\x1a\x19\n\nIdsRequest\x12\x0b\n\x03ids\x18\x01 \x03(\t\x1aP\n\x0fStatusesRequest\x12=\n\x08statuses\x18\x01 \x03(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatusB\x05\n\x03idsB\n\n\x08statuses\"\xa9\x02\n\rSessionFilter\x12\x10\n\x08sessions\x18\x01 \x03(\t\x12P\n\x08included\x18\x04 \x01(\x0b\x32<.armonik.api.grpc.v1.submitter.SessionFilter.StatusesRequestH\x00\x12P\n\x08\x65xcluded\x18\x05 \x01(\x0b\x32<.armonik.api.grpc.v1.submitter.SessionFilter.StatusesRequestH\x00\x1aV\n\x0fStatusesRequest\x12\x43\n\x08statuses\x18\x01 \x03(\x0e\x32\x31.armonik.api.grpc.v1.session_status.SessionStatusB\n\n\x08statuses\"(\n\x14GetTaskStatusRequest\x12\x10\n\x08task_ids\x18\x01 \x03(\t\"\xbf\x01\n\x12GetTaskStatusReply\x12O\n\x0bid_statuses\x18\x01 \x03(\x0b\x32:.armonik.api.grpc.v1.submitter.GetTaskStatusReply.IdStatus\x1aX\n\x08IdStatus\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12;\n\x06status\x18\x02 \x01(\x0e\x32+.armonik.api.grpc.v1.task_status.TaskStatus\"@\n\x16GetResultStatusRequest\x12\x12\n\nresult_ids\x18\x01 \x03(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\xc9\x01\n\x14GetResultStatusReply\x12Q\n\x0bid_statuses\x18\x01 \x03(\x0b\x32<.armonik.api.grpc.v1.submitter.GetResultStatusReply.IdStatus\x1a^\n\x08IdStatus\x12\x11\n\tresult_id\x18\x01 \x01(\t\x12?\n\x06status\x18\x02 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\"\x96\x01\n\x0bResultReply\x12\x30\n\x06result\x18\x01 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.DataChunkH\x00\x12/\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.TaskErrorH\x00\x12\x1c\n\x12not_completed_task\x18\x03 \x01(\tH\x00\x42\x06\n\x04type\"\x94\x01\n\x11\x41vailabilityReply\x12(\n\x02ok\x18\x01 \x01(\x0b\x32\x1a.armonik.api.grpc.v1.EmptyH\x00\x12/\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x1e.armonik.api.grpc.v1.TaskErrorH\x00\x12\x1c\n\x12not_completed_task\x18\x03 \x01(\tH\x00\x42\x06\n\x04type\"\x93\x01\n\x0bWaitRequest\x12\x39\n\x06\x66ilter\x18\x01 \x01(\x0b\x32).armonik.api.grpc.v1.submitter.TaskFilter\x12 \n\x18stop_on_first_task_error\x18\x02 \x01(\x08\x12\'\n\x1fstop_on_first_task_cancellation\x18\x03 \x01(\x08\"\xba\x01\n\x12WatchResultRequest\x12G\n\x0e\x66\x65tch_statuses\x18\x01 \x03(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12G\n\x0ewatch_statuses\x18\x02 \x03(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x12\n\nresult_ids\x18\x03 \x03(\t\"h\n\x11WatchResultStream\x12?\n\x06status\x18\x01 \x01(\x0e\x32/.armonik.api.grpc.v1.result_status.ResultStatus\x12\x12\n\nresult_ids\x18\x02 \x03(\tB \xaa\x02\x1d\x41rmoniK.Api.gRPC.V1.Submitterb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'submitter_common_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  _globals['DESCRIPTOR']._options = None
  _globals['DESCRIPTOR']._serialized_options = b'\252\002\035ArmoniK.Api.gRPC.V1.Submitter'
  _globals['_SESSIONLIST']._serialized_start=134
  _globals['_SESSIONLIST']._serialized_end=195
  _globals['_SESSIONIDLIST']._serialized_start=197
  _globals['_SESSIONIDLIST']._serialized_end=233
  _globals['_CREATESESSIONREQUEST']._serialized_start=235
  _globals['_CREATESESSIONREQUEST']._serialized_end=343
  _globals['_CREATESESSIONREPLY']._serialized_start=345
  _globals['_CREATESESSIONREPLY']._serialized_end=385
  _globals['_CREATESMALLTASKREQUEST']._serialized_start=388
  _globals['_CREATESMALLTASKREQUEST']._serialized_end=545
  _globals['_CREATELARGETASKREQUEST']._serialized_start=548
  _globals['_CREATELARGETASKREQUEST']._serialized_end=877
  _globals['_CREATELARGETASKREQUEST_INITREQUEST']._serialized_start=780
  _globals['_CREATELARGETASKREQUEST_INITREQUEST']._serialized_end=869
  _globals['_CREATETASKREPLY']._serialized_start=880
  _globals['_CREATETASKREPLY']._serialized_end=1366
  _globals['_CREATETASKREPLY_TASKINFO']._serialized_start=1015
  _globals['_CREATETASKREPLY_TASKINFO']._serialized_end=1119
  _globals['_CREATETASKREPLY_CREATIONSTATUS']._serialized_start=1121
  _globals['_CREATETASKREPLY_CREATIONSTATUS']._serialized_end=1242
  _globals['_CREATETASKREPLY_CREATIONSTATUSLIST']._serialized_start=1244
  _globals['_CREATETASKREPLY_CREATIONSTATUSLIST']._serialized_end=1354
  _globals['_TASKFILTER']._serialized_start=1369
  _globals['_TASKFILTER']._serialized_end=1810
  _globals['_TASKFILTER_IDSREQUEST']._serialized_start=1684
  _globals['_TASKFILTER_IDSREQUEST']._serialized_end=1709
  _globals['_TASKFILTER_STATUSESREQUEST']._serialized_start=1711
  _globals['_TASKFILTER_STATUSESREQUEST']._serialized_end=1791
  _globals['_SESSIONFILTER']._serialized_start=1813
  _globals['_SESSIONFILTER']._serialized_end=2110
  _globals['_SESSIONFILTER_STATUSESREQUEST']._serialized_start=2012
  _globals['_SESSIONFILTER_STATUSESREQUEST']._serialized_end=2098
  _globals['_GETTASKSTATUSREQUEST']._serialized_start=2112
  _globals['_GETTASKSTATUSREQUEST']._serialized_end=2152
  _globals['_GETTASKSTATUSREPLY']._serialized_start=2155
  _globals['_GETTASKSTATUSREPLY']._serialized_end=2346
  _globals['_GETTASKSTATUSREPLY_IDSTATUS']._serialized_start=2258
  _globals['_GETTASKSTATUSREPLY_IDSTATUS']._serialized_end=2346
  _globals['_GETRESULTSTATUSREQUEST']._serialized_start=2348
  _globals['_GETRESULTSTATUSREQUEST']._serialized_end=2412
  _globals['_GETRESULTSTATUSREPLY']._serialized_start=2415
  _globals['_GETRESULTSTATUSREPLY']._serialized_end=2616
  _globals['_GETRESULTSTATUSREPLY_IDSTATUS']._serialized_start=2522
  _globals['_GETRESULTSTATUSREPLY_IDSTATUS']._serialized_end=2616
  _globals['_RESULTREPLY']._serialized_start=2619
  _globals['_RESULTREPLY']._serialized_end=2769
  _globals['_AVAILABILITYREPLY']._serialized_start=2772
  _globals['_AVAILABILITYREPLY']._serialized_end=2920
  _globals['_WAITREQUEST']._serialized_start=2923
  _globals['_WAITREQUEST']._serialized_end=3070
  _globals['_WATCHRESULTREQUEST']._serialized_start=3073
  _globals['_WATCHRESULTREQUEST']._serialized_end=3259
  _globals['_WATCHRESULTSTREAM']._serialized_start=3261
  _globals['_WATCHRESULTSTREAM']._serialized_end=3365
# @@protoc_insertion_point(module_scope)
